@@ -3,7 +3,7 @@
     Some convenience functions
     *\file Convenience.c
     *\author $Author: thothorn $
-    *\date $Date: 2013-12-13 20:51:08 +0100 (Fre, 13 Dez 2013) $
+    *\date $Date: 2017-04-10 17:01:54 +0200 (Mon, 10 Apr 2017) $
 */
                 
 #include "party.h"
@@ -58,6 +58,8 @@ void C_LinStatExpCovMPinv(SEXP linexpcov, double tol) {
     INTEGER(GET_SLOT(GET_SLOT(linexpcov, PL2_svdmemSym), PL2_pSym))[0] = pqn;
  
     /* compute MPinv in reduced dimension */                   
+    /* GET_SLOT is assumed NOT to return a fresh object so
+       we don't PROTECT here */
     C_MPinv(GET_SLOT(linexpcov, PL2_covarianceSym), tol,
             GET_SLOT(linexpcov, PL2_svdmemSym), linexpcov);
 
